/******************************************************************************/
/* Sistemas Integrados TECNISA                                                */
/*                                                                            */
/* Compras e Suprimentos                                                      */
/*                                                                            */
/******************************************************************************/
/*                                                                            */
/* Nome: LIMPA_CMPSUP                                                         */
/*                                                                            */
/* Descrio:                                                                 */
/* Limpa as informaes de Solcitao de Compras,                             */
/* Cotao de Preos ou AF                                                    */
/*                                                                            */
/*                                                                            */
/* Criao:                                                                   */
/* 24/01/2000 - Yoris L. de Souza                                             */
/*                                                                            */
/* Manutenes:                                                               */
/* 31/01/2000 - Yoris                                                         */
/*                                                                            */
/* @C:\WIN_1.52\SQL\ORACLE\8280_CMPSTP_LIMPA_CMPSUP.SQL                        */
/*                                                                            */
/******************************************************************************/

/******************************************************************************/
/* PARAMETROS:                                                                */
/*                                                                            */
/******************************************************************************/

CREATE OR REPLACE PROCEDURE LIMPA_CMPSUP
  (P_CDCENTCMP    IN FILIAL.CDFILIAL%TYPE,
   P_CDFILLISTA   IN VARCHAR2,
   P_TCDFILIAL    IN VARCHAR2,
   P_IDLIMPSOL    IN VARCHAR2,
   P_IDLIMPCOL    IN VARCHAR2,
   P_IDLIMPAF     IN VARCHAR2,
   P_DTLIMPSOL    IN DATE DEFAULT NULL,         /* LIMPA A SOLICITAAO */
   P_DTLIMPCOT    IN DATE DEFAULT NULL,         /* LIMPA A COTAAO     */
   P_DTLIMPAF     IN DATE DEFAULT NULL,         /* LIMPA A AUTORIZAAO */
   P_DSSISTEMA    IN VARCHAR2,                  /* NOME DO SISTEMA */
   P_NMOPERADOR   IN OPERADOR.NMOPERADOR%TYPE,  /* NOME DO OPERADOR */
   P_DSLIMPSOL    IN VARCHAR2, /* TIPO DE OPERAAO _ SOLICITAAO */
   P_DSLIMPCOT    IN VARCHAR2, /* TIPO DE OPERAAO _ COTAAO */
   P_DSLIMPAF     IN VARCHAR2, /* TIPO DE OPERAAO _ AUTORIZAAO */
   P_IDLIMPOU     OUT VARCHAR2) IS

   V_IDLIMPOU  VARCHAR2(1);

   V_CDFILIAL  VARCHAR2(4);

   V_IDLIMPSOL VARCHAR2(1);
   V_IDLIMPCOL VARCHAR2(1);
   V_IDLIMPAF  VARCHAR2(1);
   V_SEGUNDO   NUMBER;

BEGIN
 V_SEGUNDO := 0;

 V_IDLIMPOU  := '0';

 V_CDFILIAL  := ' ';

 IF (P_IDLIMPSOL = 'S') THEN

    FOR C_SOLICITA IN
       (SELECT
           SOLICITA.CDFILSOLI,
           SOLICITA.CDFILLANCA,
           SOLICITA.NRSOLICMP
        FROM
           SOLICITA
        WHERE
          ((INSTR(P_CDFILLISTA, SOLICITA.CDFILSOLI) <> 0) OR P_TCDFILIAL = 'T') AND
          SOLICITA.DTSOLCMP <= P_DTLIMPSOL
        ORDER BY
           SOLICITA.CDFILSOLI)
    LOOP
       DELETE MOVSOLEXT
       WHERE
          C_SOLICITA.CDFILSOLI  = MOVSOLEXT.CDFILSOLEXT  AND
          C_SOLICITA.CDFILLANCA = MOVSOLEXT.CDFILLANCEXT AND
          C_SOLICITA.NRSOLICMP  = MOVSOLEXT.NRSOLIMOVEXT;

       DELETE MOVOPSOL
       WHERE
          C_SOLICITA.CDFILSOLI  = MOVOPSOL.CDFILSOLMOV AND
          C_SOLICITA.CDFILLANCA = MOVOPSOL.CDFILLANMOV AND
          C_SOLICITA.NRSOLICMP  = MOVOPSOL.NRSOLIMOV;

       DELETE SOLICITA
       WHERE
          CDFILSOLI  = C_SOLICITA.CDFILSOLI AND
          CDFILLANCA = C_SOLICITA.CDFILLANCA AND
          NRSOLICMP  = C_SOLICITA.NRSOLICMP;

       IF V_CDFILIAL <> C_SOLICITA.CDFILSOLI THEN
          V_CDFILIAL := C_SOLICITA.CDFILSOLI;
          INSERT INTO LOGLIMPEZA
            (DTLIMPDADOS, DSSISTLIMPEZ, NMOPERLIMPEZ,
             DTFINALIMPEZ, DSLIMPEZA)
          VALUES
             (SYSDATE + V_SEGUNDO, P_DSSISTEMA, P_NMOPERADOR,
              P_DTLIMPSOL, P_DSLIMPSOL || ' ' || C_SOLICITA.CDFILSOLI);

          V_SEGUNDO  := V_SEGUNDO + 0.00001157407407;
          V_IDLIMPOU := '1';
       END IF;

       COMMIT;
    END LOOP;

 END IF;

 V_CDFILIAL  := ' ';
 V_SEGUNDO   := 0;

 IF (P_IDLIMPCOL = 'S') THEN

    DELETE LOGCOLETAPR
    WHERE
       CDFILIALLOG = P_CDCENTCMP AND
       DTCOLEPRLOG <= P_DTLIMPCOT;

    FOR C_COLETAPR IN
       (SELECT
           COLETAPR.CDFILIAL,
           COLETAPR.NRCOLEPRECO
        FROM
           COLETAPR
        WHERE
           CDFILIAL = P_CDCENTCMP AND
           DTCOLEPREC <= P_DTLIMPCOT)
    LOOP
       DELETE ITMPREVLIST
       WHERE
          ITMPREVLIST.CDFILIAL    = C_COLETAPR.CDFILIAL AND
          ITMPREVLIST.NRCOLEPRECO = C_COLETAPR.NRCOLEPRECO;

       DELETE COLETAPR
       WHERE
          CDFILIAL    = C_COLETAPR.CDFILIAL AND
          NRCOLEPRECO = C_COLETAPR.NRCOLEPRECO;
       IF SQL%ROWCOUNT <> 0 THEN
          V_IDLIMPCOL := 'S';
       END IF;
       COMMIT;
    END LOOP;

    IF V_IDLIMPCOL = 'S' THEN

       INSERT INTO LOGLIMPEZA
         (DTLIMPDADOS, DSSISTLIMPEZ, NMOPERLIMPEZ,
          DTFINALIMPEZ, DSLIMPEZA)
       VALUES
          (SYSDATE, P_DSSISTEMA, P_NMOPERADOR,
           P_DTLIMPCOT, P_DSLIMPCOT || ' ' || P_CDCENTCMP);

       V_IDLIMPOU := '2';
    END IF;
    DELETE PREVLISTA
    WHERE
       NOT EXISTS(SELECT
                     ITMPREVLIST.CDFILIAL
                  FROM
                     ITMPREVLIST
                  WHERE
                     ITMPREVLIST.NRSEQPRELIST = PREVLISTA.NRSEQPRELIST AND
                     ITMPREVLIST.CDFILIAL     = PREVLISTA.CDFILIAL);
 END IF;

 V_CDFILIAL  := ' ';

 IF (P_IDLIMPAF = 'S') THEN
    FOR C_AUTOFORNE IN
       (SELECT
           AUTOFORNE.CDFILDEST,
           AUTOFORNE.CDFILLANC,
           AUTOFORNE.NRAUTOFORN
        FROM
           AUTOFORNE
        WHERE
         ((INSTR(P_CDFILLISTA, CDFILDEST) <> 0) OR P_TCDFILIAL = 'T') AND
         DTAUTOFORN <= P_DTLIMPAF
        ORDER BY
           AUTOFORNE.CDFILDEST)
    LOOP
       UPDATE ITEMPRODUTO
       SET
         ITEMPRODUTO.CDFILDEST   = NULL,
         ITEMPRODUTO.NRAUTOFORN  = NULL,
         ITEMPRODUTO.CDMARCA     = NULL,
         ITEMPRODUTO.DTPROGENTAF = NULL
       WHERE
         ITEMPRODUTO.CDFILDEST   = C_AUTOFORNE.CDFILDEST  AND
         ITEMPRODUTO.CDFILIAL    = C_AUTOFORNE.CDFILLANC  AND
         ITEMPRODUTO.NRAUTOFORN  = C_AUTOFORNE.NRAUTOFORN;

       DELETE NFRELACAF
       WHERE
         NFRELACAF.CDFILDEST   = C_AUTOFORNE.CDFILDEST  AND
         NFRELACAF.CDFILLANC   = C_AUTOFORNE.CDFILLANC  AND
         NFRELACAF.NRAUTOFORN  = C_AUTOFORNE.NRAUTOFORN;

       DELETE AUTOFORNE
       WHERE
          CDFILDEST   = C_AUTOFORNE.CDFILDEST AND
          CDFILLANC   = C_AUTOFORNE.CDFILLANC AND
          NRAUTOFORN  = C_AUTOFORNE.NRAUTOFORN;

       IF V_CDFILIAL <> C_AUTOFORNE.CDFILDEST THEN
          V_CDFILIAL := C_AUTOFORNE.CDFILDEST;
          INSERT INTO LOGLIMPEZA
            (DTLIMPDADOS, DSSISTLIMPEZ, NMOPERLIMPEZ,
             DTFINALIMPEZ, DSLIMPEZA)
          VALUES
             (SYSDATE + V_SEGUNDO, P_DSSISTEMA, P_NMOPERADOR,
              P_DTLIMPAF, P_DSLIMPAF || ' ' || C_AUTOFORNE.CDFILDEST);

          V_SEGUNDO  := V_SEGUNDO + 0.00001157407407;
          V_IDLIMPOU := '4';
       END IF;

       COMMIT;
    END LOOP;
 END IF;
 P_IDLIMPOU := V_IDLIMPOU;
END;
/